#include "common.h"

// ROOT headers
#include "TF1.h"
#include "TPad.h"
#include "TPaveText.h"

/* Draw original, unweighted plots and ratio plot below them
   Flag isW determines the range for the ratio axis. */
void draw3(TCanvas *c, TH1D *h1, TH1D *h2, TH1D *hdiff, bool isW, TString fit, Double_t x0, Double_t x1) {
    c->Clear();

    TPad *c1npad1, *c1npad2, *c1npad3 = NULL;
    if (fit == "") {
        c1npad1 = new TPad("c1npad1", "", 0, 0.2, 1, 1, kWhite); // create pad for the plots
        c1npad2 = new TPad("c1napd2", "", 0, 0, 1, 0.25, kWhite); // create pad for the ratio
    } else {
        c1npad1 = new TPad("c1npad1", "", 0, 0.4, 1, 1, kWhite); // create pad for the plots
        c1npad2 = new TPad("c1napd2", "", 0, 0.2, 1, 0.4, kWhite); // create pad for the ratio
        c1npad3 = new TPad("c1napd3", "", 0, 0, 1, 0.2, kWhite);
    }

    c->cd();
    c1npad1->SetFillColor(kWhite);
    c1npad1->Draw(); // draw larger pad in main area
    c1npad1->cd();   // change working area to inside main pad

    double max1=h1->GetMaximum();
    double max2=h2->GetMaximum();
    double max= max1>max2 ? max1:max2;

    h1->GetYaxis()->SetRangeUser(0,max*1.1);

    h1->SetLineColor(2);
    h1->SetStats(0);
    h1->Draw("hist");

    h2->SetLineColor(3);
    h2->SetStats(0);
    h2->Draw("hist same");

    Double_t N1, N2;
    Double_t P1, P2;
    Double_t P1e, P2e;
    TF1 *ffit1, *ffit2;

    if (fit != "") {
        ffit1 = new TF1("ffit1", fit, x0, x1);
        ffit1->SetLineColor(kBlue);
        h1->Fit("ffit1", "RN", "SAME");

        P1 = ffit1->GetParameter(0);
        N1 = ffit1->GetParameter(1);
        P1e = ffit1->GetParError(0);

        ffit2 = new TF1("ffit2", fit, x0, x1);
        ffit2->SetLineColor(kBlack);
        h2->Fit("ffit2", "RN", "SAME");

        P2 = ffit2->GetParameter(0);
        N2 = ffit2->GetParameter(1);
        P2e = ffit2->GetParError(0);
    }

    c->cd();        // go back to working area of whole canvas
    c1npad2->SetFillColor(kWhite);
    c1npad2->Draw(); // draw smaller pad in main canvas
    c1npad2->cd();   // set working area to smaller pad

    max1 = hdiff->GetMinimum();
    max2 = hdiff->GetMaximum();

    hdiff->SetLineColor(kBlack);
    hdiff->SetStats(0); // setup the options for the ratio plot
    hdiff->SetTitle(NULL);
    hdiff->GetYaxis()->SetTitle("Ratio");
    hdiff->GetYaxis()->SetTitleSize(0.12);
    hdiff->GetYaxis()->SetTitleOffset(0.3);
    hdiff->GetYaxis()->SetLabelSize(0.1);
    hdiff->GetXaxis()->SetLabelSize(0.1);
    if(isW) hdiff->GetYaxis()->SetRangeUser(0,2);
    else    hdiff->GetYaxis()->SetRangeUser(0.75,1.25);
    hdiff->GetYaxis()->SetNdivisions(4,kTRUE);
    hdiff->SetTickLength(0.01,"Y");
    hdiff->SetMarkerStyle(7);
    hdiff->DrawCopy("p e"); // draw the ratio plot

    TF1 *line_1 = new TF1("line_1", "1", 0, 1);
    line_1->SetLineColor(kBlack);
    line_1->Draw("SAME");

    if (fit != "") {
        TString fit1 = fit;
        fit1 = fit1.ReplaceAll("[0]", TString("(") + TString::Format("%f", P1) + ")");
        fit1 = fit1.ReplaceAll("[1]", TString("(") + TString::Format("%f", N1) + ")");

        TString fit2 = fit;
        fit2 = fit2.ReplaceAll("[0]", TString("(") + TString::Format("%f", P2) + ")");
        fit2 = fit2.ReplaceAll("[1]", TString("(") + TString::Format("%f", N2) + ")");

        TString fitratio = TString("(") + fit1 + ")/(" + fit2 + ")";

        TF1 *ffitratio = new TF1("fitration", fitratio, x0, x1);
        ffitratio->SetLineColor(kBlue);
        ffitratio->SetLineWidth(1);
        ffitratio->Draw("SAME");
    }

    c->cd(); // go back to main canvas

    if (fit != "") {
        c1npad3->SetFillColor(kWhite);
        c1npad3->Draw(); // draw smaller pad in main canvas
        c1npad3->cd();   // set working area to smaller pad

        TString p_orig = "P_{orig} = " + TString::Format("%.2e", P1) + " #pm " + TString::Format("%.2e", P1e);
        TString p_unweighted = "P_{unweighted} = " + TString::Format("%.2e", P2) + " #pm " + TString::Format("%.2e", P2e);

        TPaveText *pt = new TPaveText(.05,.1,.95,.8);
        pt->SetTextSize(0.18);
        pt->SetFillColor(kWhite);
        pt->AddText(p_orig);
        pt->AddText(p_unweighted);
        
        pt->SetBorderSize(0);
        pt->Draw();

        c->cd();
    }
}
